@@ -5,7 +5,7 @@ from PyQt5 import uic
 import PyQt5.QtGui as Qg
 import PyQt5.QtWidgets as Qw
 from PyQt5.QtCore import Qt
-from store_data import integration as cypherQuery
+import nestor_qt.store_data.integration as cypherQuery
 
 import pyaml
 import yaml
